<?xml version="1.0" ?><!DOCTYPE TS><TS language="uk" version="2.1">
<context>
    <name>AboutDialog</name>
    <message>
        <source>Deepin Image Viewer</source>
        <translation>Переглядач зображень Deepin</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>Версія:</translation>
    </message>
</context>
<context>
    <name>AlbumBTContent</name>
    <message>
        <source>image</source>
        <translation>зображення</translation>
    </message>
    <message>
        <source>images</source>
        <translation>зображень</translation>
    </message>
    <message>
        <source>album</source>
        <translation>альбом</translation>
    </message>
    <message>
        <source>albums</source>
        <translation>альбоми</translation>
    </message>
    <message>
        <source>Manage sync</source>
        <translation>Керування синхронізацією</translation>
    </message>
    <message>
        <source>Syncing: </source>
        <translation>Синхронізація:</translation>
    </message>
</context>
<context>
    <name>AlbumCreateDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Гаразд</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Новий альбом</translation>
    </message>
    <message>
        <source>Unnamed</source>
        <translation>Без назви</translation>
    </message>
</context>
<context>
    <name>AlbumDelegate</name>
    <message>
        <source>Recent imported</source>
        <translation>Нещодавно імпортовано</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Моє обране</translation>
    </message>
</context>
<context>
    <name>AlbumDeleteDialog</name>
    <message>
        <source>Are your sure to delete this album?</source>
        <translation>Ви впевнені, що хочете видалити цей альбом?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Вилучити</translation>
    </message>
</context>
<context>
    <name>AlbumPanel</name>
    <message>
        <source>Back</source>
        <translation>Назад</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Моє обране</translation>
    </message>
    <message>
        <source>Timeline</source>
        <translation>Шкала часу</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Додати</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Ви можете додати директорію синхронізації або перетягнути зображення до шкали часу</translation>
    </message>
</context>
<context>
    <name>AlbumsView</name>
    <message>
        <source>Unnamed</source>
        <translation>Без назви</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Вид</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Показ слайдів</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Перейменувати</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Скопіювати</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Вилучити</translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <source>Deepin Image Viewer</source>
        <translation>Переглядач зображень Deepin</translation>
    </message>
</context>
<context>
    <name>CountingThread</name>
    <message>
        <source>Images</source>
        <translation>Зображення</translation>
    </message>
</context>
<context>
    <name>DirImportDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Гаразд</translation>
    </message>
    <message>
        <source>Are you sure to add the pictures to the album?</source>
        <translation>Ви впевнені, що додали фотографії в альбом?</translation>
    </message>
    <message>
        <source>Sync and Create</source>
        <translation>Синхронізувати та створити</translation>
    </message>
    <message>
        <source>Sync</source>
        <translation>Синхронізувати</translation>
    </message>
    <message>
        <source>Are you sure to add to the sync list and create the album named after this folder?</source>
        <translation>Чи потрібно додавати до списку синхронізації і створювати альбом, названий на честь цієї теки?</translation>
    </message>
</context>
<context>
    <name>Exporter</name>
    <message>
        <source>JPEG(*.bmp *.gif *.jpg; *.jpeg; *.png *.pbm;*.pgm *.ppm *.xbm *.xpm *.svg *.dds *.icns*.jp2 *.mng *.tga *.tiff *.wbmp *.webp;)</source>
        <translation>JPEG(*.bmp *.gif *.jpg; *.jpeg; *.png *.pbm;*.pgm *.ppm *.xbm *.xpm *.svg *.dds *.icns*.jp2 *.mng *.tga *.tiff *.wbmp *.webp;)</translation>
    </message>
    <message>
        <source>Exported successfully</source>
        <translation>Експортовано успішно</translation>
    </message>
    <message>
        <source>Failed to export</source>
        <translation>Не вдалося експортувати</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Зберегти</translation>
    </message>
</context>
<context>
    <name>FileDeleteDialog</name>
    <message>
        <source>Are you sure to throw pictures to TRASH?</source>
        <translation>Ви дійсно хочете перемістити фотографії до СМІНИКУ?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Вилучити</translation>
    </message>
</context>
<context>
    <name>ImageInfoWidget</name>
    <message>
        <source>Image info</source>
        <translation>Інформація про зображення</translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <source>This file contains multiple pages, please use Evince to view all pages.</source>
        <translation>Цей файл містить декілька сторінок, будь ласка, запустіть Evince для перегляду усіх сторінок.</translation>
    </message>
</context>
<context>
    <name>ImagesView</name>
    <message>
        <source>View</source>
        <translation>Вид</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Повноекранний</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Слайд шоу</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Друк</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Скопіювати</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Копіювати в буфер обміну</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Видалити з альбому</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Моє обране</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Вилучити з Обраного</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Повернути за годинниковою стрілкою</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Повернути проти годинникової стрілки</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Встановити як шпалери</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Показати в файловому менеджері</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Інформація про зображення</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Додати</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Ви можете додати директорію синхронізації або перетягнути зображення до шкали часу</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Додати до альбому</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Додати до нового альбому</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Вилучити</translation>
    </message>
</context>
<context>
    <name>Importer</name>
    <message>
        <source>Open Directory</source>
        <translation>Відкрити Директорію</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>Ви не маєте дозволу на перегляд зображення</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Ім&apos;я</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message>
        <source>Date photoed</source>
        <translation>Дата фотографування</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Дата зміни</translation>
    </message>
    <message>
        <source>Dimension</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File size</source>
        <translation>Розмір файлу</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Кольорова палітра</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Режим експозиції</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Програма експозиції</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Час експозиції</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Спалах</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Діафрагма</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Фокусна відстань</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Макс. діафрагма</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Режим виміру експозиції</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Баланс білого</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Компенсація спалаху</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Модель камери</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Модель об&apos;єктиву</translation>
    </message>
</context>
<context>
    <name>PrintOptionsPage</name>
    <message>
        <source>No scaling</source>
        <translation>Не масштабувати</translation>
    </message>
    <message>
        <source>Fit page to image</source>
        <translation>Вписати сторінку у зображення</translation>
    </message>
    <message>
        <source>Fit image to page</source>
        <translation>Вписати зображення у сторінку</translation>
    </message>
    <message>
        <source>Scale to:</source>
        <translation>Масштабувати:</translation>
    </message>
    <message>
        <source>Millimeters</source>
        <translation>Міліметри</translation>
    </message>
    <message>
        <source>Centimeters</source>
        <translation>Сантиметри</translation>
    </message>
    <message>
        <source>Inches</source>
        <translation>Дюйми</translation>
    </message>
    <message>
        <source>Image Position</source>
        <translation>Позиція зображення</translation>
    </message>
    <message>
        <source>Scaling</source>
        <translation>Масштаб</translation>
    </message>
    <message>
        <source>Image Settings</source>
        <translation>Налаштування зображення</translation>
    </message>
</context>
<context>
    <name>PrintPreviewDialog</name>
    <message>
        <source>Image Settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Blinds</source>
        <translation>Blinds</translation>
    </message>
    <message>
        <source>Switcher</source>
        <translation>Switcher</translation>
    </message>
    <message>
        <source>Sliding</source>
        <translation>Sliding</translation>
    </message>
    <message>
        <source>Ring</source>
        <translation>Ring</translation>
    </message>
</context>
<context>
    <name>ScanPathsDialog</name>
    <message>
        <source>Select Directory</source>
        <translation>Вибрати Директорію</translation>
    </message>
    <message>
        <source>This directory is disabled to sync</source>
        <translation>Цю директорію вимкнено для синхронізації</translation>
    </message>
    <message>
        <source>Add folder</source>
        <translation>Додати теку</translation>
    </message>
    <message>
        <source>Sync Directory Management</source>
        <translation>Керування Директорією Синхронізації</translation>
    </message>
    <message>
        <source>The directory list is empty</source>
        <translation>Список директорій порожній</translation>
    </message>
</context>
<context>
    <name>ScanPathsItem</name>
    <message>
        <source>Cancel sync</source>
        <translation>Скасувати синхронізацію</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Зображення</translation>
    </message>
    <message>
        <source>The device has been removed</source>
        <translation>Пристрій було вилучено</translation>
    </message>
    <message>
        <source>This directory no longer exists</source>
        <translation>Ця директорія більше не існує</translation>
    </message>
    <message>
        <source>Calculating...</source>
        <translation>Розрахунок...</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Image Viewing</source>
        <translation>Перегляд зображень</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Альбом</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Налаштування</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Вид</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Повноекранний</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Слайд шоу</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Кінець шоу</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Скопіювати</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Видалити з альбому</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Обране</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Вилучити з Обраного</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Повернути за годинниковою стрілкою</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Повернути проти годинникової стрілки</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Встановити як шпалери</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Показати в файловому менеджері</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Інформація про зображення</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Попередній</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Наступний</translation>
    </message>
    <message>
        <source>Previous screen</source>
        <translation>Попередній екран</translation>
    </message>
    <message>
        <source>Next screen</source>
        <translation>Наступний екран</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Новий альбом</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Перейменувати</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Допомога</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Вихід</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Показати ярлики</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Вилучити</translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>Please enter a new shortcut</source>
        <translation>Будь ласка, введіть новий ярлик</translation>
    </message>
</context>
<context>
    <name>ShortcutFrame</name>
    <message>
        <source>Shortcuts</source>
        <translation>Ярлики</translation>
    </message>
    <message>
        <source>View Picture</source>
        <translation>Переглянути фотографію</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Альбом</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>Відновити за замовчуванням</translation>
    </message>
</context>
<context>
    <name>ShortcutKey</name>
    <message>
        <source>View</source>
        <translation>Вид</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Повноекранний</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Слайд шоу</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Кінець шоу</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Друк</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Скопіювати</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Видалити з альбому</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Обране</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Вилучити з Обраного</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Повернути за годинниковою стрілкою</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Повернути проти годинникової стрілки</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Встановити як шпалери</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Показати в файловому менеджері</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Інформація про зображення</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Новий альбом</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Перейменувати</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Вилучити</translation>
    </message>
</context>
<context>
    <name>SlideShowPanel</name>
    <message>
        <source>End show</source>
        <translation>Кінець шоу</translation>
    </message>
    <message>
        <source>Pause/Play</source>
        <translation>Пауза/Відтворення</translation>
    </message>
</context>
<context>
    <name>SlideshowFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Параметри слайдів</translation>
    </message>
    <message>
        <source>Switch effect</source>
        <translation>Ефект перемикання</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Тривалість</translation>
    </message>
    <message>
        <source>Switch duration</source>
        <translation>Тривалість перемикання</translation>
    </message>
    <message>
        <source>second</source>
        <translation>секунд</translation>
    </message>
</context>
<context>
    <name>TTLContent</name>
    <message>
        <source>Back</source>
        <translation>Назад</translation>
    </message>
    <message>
        <source>Image management</source>
        <translation>Керування зображеннями</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Моє обране</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>Розмір 1:1</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Підібрати розмір за вікном</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Повернути проти годинникової стрілки</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Повернути за годинниковою стрілкою</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Вилучити з улубленого</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Улюблене</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Вилучити</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>Не знайдено файлів зображень</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Відкрити зображення</translation>
    </message>
</context>
<context>
    <name>TimelineBTContent</name>
    <message>
        <source>%1 image</source>
        <translation>%1 зображення</translation>
    </message>
    <message>
        <source>%1 images</source>
        <translation>%1 зображення</translation>
    </message>
    <message>
        <source>Manage sync</source>
        <translation>Керування синхронізацією</translation>
    </message>
    <message>
        <source>Syncing: </source>
        <translation>Синхронізація:</translation>
    </message>
</context>
<context>
    <name>TimelinePanel</name>
    <message>
        <source>Album</source>
        <translation>Альбом</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Додати</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Ви можете додати директорію синхронізації або перетягнути зображення до шкали часу</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Додати до альбому</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Додати до нового альбому</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Вид</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Повноекранний</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Слайд шоу</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Друк</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Скопіювати</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Копіювати в буфер обміну</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Обране</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Вилучити з Обраного</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Повернути за годинниковою стрілкою</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Повернути проти годинникової стрілки</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Встановити як шпалери</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Показати в файловому менеджері</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Інформація про зображення</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Вилучити</translation>
    </message>
</context>
<context>
    <name>TitleFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Параметри слайдів</translation>
    </message>
    <message>
        <source>Effect</source>
        <translation>Ефект</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Тривалість</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Ярлики</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Вид</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Альбом</translation>
    </message>
</context>
<context>
    <name>TopAlbumTips</name>
    <message>
        <source>dd MMMM yyyy</source>
        <translation>dd MMMM yyyy</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Моє обране</translation>
    </message>
    <message>
        <source>Recent imported</source>
        <translation>Нещодавно імпортовано</translation>
    </message>
</context>
<context>
    <name>TopToolbar</name>
    <message>
        <source>New album</source>
        <translation>Новий альбом</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Налаштування</translation>
    </message>
    <message>
        <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
        <translation>Deepin Image Viewer - це модний та плавний менеджер зображень.</translation>
    </message>
    <message>
        <source>It is featured with image management, image viewing and basic image editing.</source>
        <translation>Він призначений для керування зображеннями, перегляду зображень і основного редагування зображень.</translation>
    </message>
    <message>
        <source>Dark theme</source>
        <translation>Темна тема</translation>
    </message>
    <message>
        <source>Deepin Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>Переглядач зображень Deepin — програма для перегляду зображень із сучасним інтерфейсом та зручностями у користуванні.</translation>
    </message>
</context>
<context>
    <name>ViewPanel</name>
    <message>
        <source>Timeline</source>
        <translation>Шкала часу</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Додати до альбому</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Додати до нового альбому</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Вийти з повноекранного режиму</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Повноекранний</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Слайд шоу</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Друк</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Скопіювати</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Копіювати в буфер обміну</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Видалити з альбому</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Обране</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Вилучити з Обраного</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Показати вікно навігації</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Сховати навігаційне вікно</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Повернути за годинниковою стрілкою</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Повернути проти годинникової стрілки</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Встановити як шпалери</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Показати в файловому менеджері</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Інформація про зображення</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Вилучити</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Відкрити зображення</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>усі зображення</translation>
    </message>
</context>
</TS>